#!/bin/sh

echo "+++++ Checking current user rights..."

if [ "$(id -u root)" = "$(id -u)" ] ; then
    echo "Passed..."
else
    echo "ERROR: The current user id is not root (`id|awk '{print $1}'`)."
    exit 1
fi
echo

if [ "X$PVSW_ROOT" = "X" ] ; then
    PVSW_ROOT=/usr/local/psql
fi

LIBDIR=lib64
if [ -f $PVSW_ROOT/bin/mkded ]; then
    file -L $PVSW_ROOT/bin/mkded | grep "ELF 32-bit" >/dev/null 2>&1
    if [ $? -eq 0 ] ; then
        LIBDIR=lib
    fi
fi

PATH=$PVSW_ROOT/bin:$PATH
if [ $(uname -s) = "Darwin" ]
then
    DYLD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    SO_EXTENSION="dylib"
else
    LD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/$LIBDIR:$LD_LIBRARY_PATH
    SO_EXTENSION="so"
fi


echo "+++++ Checking for system dependencies..."

# Default values assume 64-bit is x86_64 and 32-bit is x86.
ELF64_TEXT="ELF 64-bit LSB shared object"
ELF64_LIB="/lib64/ld-linux-x86-64.${SO_EXTENSION}.2"
ELF32_TEXT="ELF 32-bit LSB shared object"
ELF32_LIB="/lib/ld-linux.${SO_EXTENSION}.2"

UNAME_PROC=`uname -mp`
echo $UNAME_PROC | grep "aarch64" >/dev/null
if [ $? -eq 0 ] ; then
    # 64-bit ARM
    ELF64_TEXT="ELF 64-bit LSB shared object, ARM aarch64"
    ELF64_LIB="/lib64/ld-linux-aarch64.${SO_EXTENSION}.1"
fi
echo $UNAME_PROC | grep "armv" >/dev/null
if [ $? -eq 0 ] ; then
    # 32-bit ARM
    ELF32_TEXT="ELF 32-bit LSB shared object, ARM"
    ELF32_LIB="/lib/ld-linux-armhf.${SO_EXTENSION}.3"
fi

if [ $(uname -s) != "Darwin" ]
then
    if [ -f /usr/local/psql/lib64/libpsqlmif.${SO_EXTENSION}.* ] ; then
        file -L $ELF64_LIB | grep "$ELF64_TEXT" >/dev/null 2>&1
        if [ $? -ne 0 ] ; then
            echo "ERROR: $ELF64_LIB not found. This package requires 64-bit runtime library support."
            exit 1
        fi
    fi
    MIF=`ls -1 /usr/local/psql/lib/libpsqlmif.${SO_EXTENSION}.* 2>/dev/null | grep -v debug`
    if [ "X$MIF" != "X" ] ; then
	ldd $MIF | grep 'ld-linux' | grep 'not found'
        if [ $? -eq 0 ] ; then
            echo "ERROR: $ELF32_LIB not found. This package requires 32-bit runtime library support."
            exit 1
        fi
    fi
fi

echo "Passed..."
echo
